@@ -131,13 +131,13 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
   (void) SetImageProperty(image,"label",label,exception);
   draw_info=CloneDrawInfo(image_info,(DrawInfo *) NULL);
   width=(size_t) floor(draw_info->pointsize*strlen(label)+0.5);
-  draw_info->text=ConstantString(label);
-  label=DestroyString(label);
   if (AcquireMagickResource(WidthResource,width) == MagickFalse)
     {
+      label=DestroyString(label);
       draw_info=DestroyDrawInfo(draw_info);
       ThrowReaderException(ImageError,"WidthOrHeightExceedsLimit");
     }
+  draw_info->text=ConstantString(label);
   (void) memset(&metrics,0,sizeof(metrics));
   status=GetMultilineTypeMetrics(image,draw_info,&metrics,exception);
   if ((image->columns == 0) && (image->rows == 0))
@@ -146,7 +146,7 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
       image->rows=(size_t) floor(metrics.height+draw_info->stroke_width+0.5);
     }
   else
-    if ((status != MagickFalse) && (strlen(draw_info->text) > 0) &&
+    if ((status != MagickFalse) && (strlen(label) > 0) &&
         (((image->columns == 0) || (image->rows == 0)) ||
          (fabs(image_info->pointsize) < MagickEpsilon)))
       {
@@ -160,7 +160,6 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
         /*
           Auto fit text into bounding box.
         */
-        (void) ConcatenateString(&draw_info->text,":");
         for (n=0; n < 32; n++, draw_info->pointsize*=2.0)
         {
           (void) FormatLocaleString(geometry,MagickPathExtent,"%+g%+g",
@@ -184,6 +183,7 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
         }
         if (status == MagickFalse)
           {
+            label=DestroyString(label);
             draw_info=DestroyDrawInfo(draw_info);
             image=DestroyImageList(image);
             return((Image *) NULL);
@@ -215,13 +215,13 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
             else
               high=draw_info->pointsize-0.5;
         }
-        draw_info->text[strlen(draw_info->text)-1]='\0';
         if (status != MagickFalse)
           {
             draw_info->pointsize=floor((low+high)/2.0-0.5);
             status=GetMultilineTypeMetrics(image,draw_info,&metrics,exception);
           }
       }
+   label=DestroyString(label);
    if (status == MagickFalse)
      {
        draw_info=DestroyDrawInfo(draw_info);
@@ -261,14 +261,8 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
   (void) CloneString(&draw_info->geometry,geometry);
   status=AnnotateImage(image,draw_info,exception);
   if (image_info->pointsize == 0.0)
-    {
-      char
-        pointsize[MagickPathExtent];
-
-      (void) FormatLocaleString(pointsize,MagickPathExtent,"%.20g",
-        draw_info->pointsize);
-      (void) SetImageProperty(image,"label:pointsize",pointsize,exception);
-    }
+    (void) FormatImageProperty(image,"label:pointsize","%.20g",
+      draw_info->pointsize);
   draw_info=DestroyDrawInfo(draw_info);
   if (status == MagickFalse)
     {
